$(document).ready(function() {
  "use strict";
 // const {readFileSync, promises: fsPromises} = require('fs');
  // Set the Bing API key for Bing Maps
  // Without your own key you will be using a limited WorldWind developer's key.
  // See: https://www.bingmapsportal.com/ to register for your own key and then enter it below:
  const BING_API_KEY = "";
  if (BING_API_KEY) {
    // Initialize WorldWind properties before creating the first WorldWindow
    WorldWind.BingMapsKey = BING_API_KEY;
  } else {
    console.error("app.js: A Bing API key is required to use the Bing maps in production. Get your API key at https://www.bingmapsportal.com/");
  }
  // Set the MapQuest API key used for the Nominatim service.
  // Get your own key at https://developer.mapquest.com/
  // Without your own key you will be using a limited WorldWind developer's key.
  const MAPQUEST_API_KEY = "";

  /**
   * The Globe encapsulates the WorldWindow object (wwd) and provides application
   * specific logic for interacting with layers.
   * @param {String} canvasId The ID of the canvas element that will host the globe
   * @returns {Globe}
   */
  class Globe {
    constructor(canvasId, projectionName) {
      // Create a WorldWindow globe on the specified HTML5 canvas
      this.wwd = new WorldWind.WorldWindow(canvasId);

      // Projection support
      this.roundGlobe = this.wwd.globe; // The default is a 3D globe
      this.flatGlobe = null;
      if (projectionName) {
        this.changeProjection(projectionName);
      }

      // Holds the next unique id to be assigned to a layer
      this.nextLayerId = 1;

      // Holds a map of category and observable timestamp pairs
      this.categoryTimestamps = new Map();


      // Add a BMNGOneImageLayer background layer. We're overriding the default 
      // minimum altitude of the BMNGOneImageLayer so this layer always available.
      this.addLayer(new WorldWind.BMNGOneImageLayer(), {
        category: "background",
        minActiveAltitude: 0
      });

    }

    /**
     * Returns the supported projection names.
     * @returns {Array} 
     */
    get projectionNames() {
      return [
        "3D",
        "Equirectangular",
        "Mercator",
        "North Polar",
        "South Polar",
        "North UPS",
        "South UPS",
        "North Gnomonic",
        "South Gnomonic"
      ];
    }
    /**
     * Changes the globe's projection.
     * @param {String} projectionName
     */
    changeProjection(projectionName) {
      if (projectionName === "3D") {
        if (!this.roundGlobe) {
          this.roundGlobe = new WorldWind.Globe(new WorldWind.EarthElevationModel());
        }
        if (this.wwd.globe !== this.roundGlobe) {
          this.wwd.globe = this.roundGlobe;
        }
      } else {
        if (!this.flatGlobe) {
          this.flatGlobe = new WorldWind.Globe2D();
        }
        if (projectionName === "Equirectangular") {
          this.flatGlobe.projection = new WorldWind.ProjectionEquirectangular();
        } else if (projectionName === "Mercator") {
          this.flatGlobe.projection = new WorldWind.ProjectionMercator();
        } else if (projectionName === "North Polar") {
          this.flatGlobe.projection = new WorldWind.ProjectionPolarEquidistant("North");
        } else if (projectionName === "South Polar") {
          this.flatGlobe.projection = new WorldWind.ProjectionPolarEquidistant("South");
        } else if (projectionName === "North UPS") {
          this.flatGlobe.projection = new WorldWind.ProjectionUPS("North");
        } else if (projectionName === "South UPS") {
          this.flatGlobe.projection = new WorldWind.ProjectionUPS("South");
        } else if (projectionName === "North Gnomonic") {
          this.flatGlobe.projection = new WorldWind.ProjectionGnomonic("North");
        } else if (projectionName === "South Gnomonic") {
          this.flatGlobe.projection = new WorldWind.ProjectionGnomonic("South");
        }
        if (this.wwd.globe !== this.flatGlobe) {
          this.wwd.globe = this.flatGlobe;
        }
      }
    }

    /**
     * Returns an observable containing the last update timestamp for the category.
     * @param {String} category
     * @returns {Observable} 
     */
    getCategoryTimestamp(category) {
      if (!this.categoryTimestamps.has(category)) {
        this.categoryTimestamps.set(category, ko.observable());
      }
      return this.categoryTimestamps.get(category);
    }

    /**
     * Updates the timestamp for the given category.
     * @param {String} category
     */
    updateCategoryTimestamp(category) {
      let timestamp = this.getCategoryTimestamp(category);
      timestamp(new Date());
    }

    /**
     * Toggles the enabled state of the given layer and updates the layer
     * catetory timestamp. Applies a rule to the 'base' layers the ensures
     * only one base layer is enabled.
     * @param {WorldWind.Layer} layer
     */
    toggleLayer(layer) {

      // Multiplicity Rule: only [0..1] "base" layers can be enabled at a time
      if (layer.category === 'base') {
        this.wwd.layers.forEach(function(item) {
          if (item.category === 'base' && item !== layer) {
            item.enabled = false;
          }
        });
      }
      // Toggle the selected layer's visibility
      layer.enabled = !layer.enabled;
      // Trigger a redraw so the globe shows the new layer state ASAP
      this.wwd.redraw();

      // Signal a change in the category
      this.updateCategoryTimestamp(layer.category);
    }

    /**
     * Adds a layer to the globe. Applies the optional options' properties to the
     * layer, and assigns the layer a unique ID and category.
     * @param {WorldWind.Layer} layer
     * @param {Object|null} options E.g., {category: "base", enabled: true}
     */
    addLayer(layer, options) {
      // Copy all properties defined on the options object to the layer
      if (options) {
        for (let prop in options) {
          if (!options.hasOwnProperty(prop)) {
            continue; // skip inherited props
          }
          layer[prop] = options[prop];
        }
      }
      // Assign a default category property if not already assigned
      if (typeof layer.category === 'undefined') {
        layer.category = 'overlay'; // the default category
      }

      // Assign a unique layer ID to ease layer management 
      layer.uniqueId = this.nextLayerId++;

      // Add the layer to the globe
      this.wwd.addLayer(layer);

      // Signal that this layer category has changed
      this.getCategoryTimestamp(layer.category);
    }

    /**
     * Returns a new array of layers in the given category.
     * @param {String} category E.g., "base", "overlay" or "setting".
     * @returns {Array}
     */
    getLayers(category) {
      return this.wwd.layers.filter(layer => layer.category === category);
    }
  }

  /**
   * View model for the layers panel.
   * @param {Globe} globe - Our globe object
   */
  function LayersViewModel(globe) {
    var self = this;
    self.baseLayers = ko.observableArray(globe.getLayers('base').reverse());
    self.overlayLayers = ko.observableArray(globe.getLayers('overlay').reverse());

    // Update the view model whenever the model changes
    globe.getCategoryTimestamp('base').subscribe(newValue =>
      self.loadLayers(globe.getLayers('base'), self.baseLayers));

    globe.getCategoryTimestamp('overlay').subscribe(newValue =>
      self.loadLayers(globe.getLayers('overlay'), self.overlayLayers));

    // Utility to load the layers in reverse order to show last rendered on top
    self.loadLayers = function(layers, observableArray) {
      observableArray.removeAll();
      layers.reverse().forEach(layer => observableArray.push(layer));
    };

    // Click event handler for the layer panel's buttons
    self.toggleLayer = function(layer) {
      globe.toggleLayer(layer);
    };
  }

  /**
   * View model for the settings.
   * @param {Globe} globe - Our globe object (not a WorldWind.Globe)
   */
  function SettingsViewModel(globe) {
    var self = this;
    self.settingLayers = ko.observableArray(globe.getLayers('setting').reverse());

    // Update the view model whenever the model changes
    globe.getCategoryTimestamp('setting').subscribe(newValue =>
      self.loadLayers(globe.getLayers('setting'), self.settingLayers));

    // Utility to load layers in reverse order 
    self.loadLayers = function(layers, observableArray) {
      observableArray.removeAll();
      layers.reverse().forEach(layer => observableArray.push(layer));
    };

    // Click event handler for the setting panel's buttons
    self.toggleLayer = function(layer) {
      globe.toggleLayer(layer);
    };
  }

  /**
   * Search view model. Uses the MapQuest Nominatim API. 
   * Requires an access key. See: https://developer.mapquest.com/
   * @param {Globe} globe
   * @param {Function} preview Function to preview the results
   * @returns {SearchViewModel}
   */
  function SearchViewModel(globe, preview) {
    var self = this;
    self.geocoder = new WorldWind.NominatimGeocoder();
    self.searchText = ko.observable('');
    self.performSearch = function() {
      if (!MAPQUEST_API_KEY) {
        console.error("SearchViewModel: A MapQuest API key is required to use the geocoder in production. Get your API key at https://developer.mapquest.com/");
      }
      // Get the value from the observable
      let queryString = self.searchText();
      if (queryString) {
        if (queryString.match(WorldWind.WWUtil.latLonRegex)) {
          // Treat the text as a lat, lon pair 
          let tokens = queryString.split(",");
          let latitude = parseFloat(tokens[0]);
          let longitude = parseFloat(tokens[1]);
          // Center the globe on the lat, lon
          globe.wwd.goTo(new WorldWind.Location(latitude, longitude));
        } else {
          // Treat the text as an address or place name
          self.geocoder.lookup(queryString, function(geocoder, results) {
            if (results.length > 0) {
              // Open the modal dialog to preview and select a result
              preview(results);
            }
          }, MAPQUEST_API_KEY);
        }
      }
    };
  }

  /**
   * Read a data file sychronously...
   *  
   */
//  const {readFileSync, promises: fsPromises} = require('fs');
    
    function readSyncfile(filename) {
	var contents = readFileSync(filename, 'utf-8')

	arr = contents.split(/\r?\n/);
	for (var i=1; i < end; i++) {
	    arr[i] = parseFloat(arr[i]);
	    arr[i] = arr[i].toPrecision(3);
	}

	return arr;
    }

  /**
   * Define the view model for the Search Preview.
   * @param {Globe} primaryGlobe
   * @returns {PreviewViewModel}
   */
  function PreviewViewModel(primaryGlobe) {
    var self = this;
    // Show a warning message about the MapQuest API key if missing
    this.showApiWarning = (MAPQUEST_API_KEY === null || MAPQUEST_API_KEY === "");

    // Create secondary globe with a 2D Mercator projection for the preview
    this.previewGlobe = new Globe("preview-canvas", "Mercator");
    let resultsLayer = new WorldWind.RenderableLayer("Results");
    let bingMapsLayer = new WorldWind.BingRoadsLayer();
    bingMapsLayer.detailControl = 1.25; // Show next level-of-detail sooner. Default is 1.75
    this.previewGlobe.addLayer(bingMapsLayer);
    this.previewGlobe.addLayer(resultsLayer);

    // Set up the common placemark attributes for the results
    let placemarkAttributes = new WorldWind.PlacemarkAttributes(null);
    placemarkAttributes.imageSource = WorldWind.configuration.baseUrl + "images/pushpins/castshadow-red.png";
    placemarkAttributes.imageScale = 0.5;
    placemarkAttributes.imageOffset = new WorldWind.Offset(
      WorldWind.OFFSET_FRACTION, 0.3,
      WorldWind.OFFSET_FRACTION, 0.0);

    // Create an observable array who's contents are displayed in the preview
    this.searchResults = ko.observableArray();
    this.selected = ko.observable();

    // Shows the given search results in a table with a preview globe/map
    this.previewResults = function(results) {
      if (results.length === 0) {
        return;
      }
      // Clear the previous results
      self.searchResults.removeAll();
      resultsLayer.removeAllRenderables();
      // Add the results to the observable array
      results.map(item => self.searchResults.push(item));
      // Create a simple placemark for each result
      for (let i = 0, max = results.length; i < max; i++) {
        let item = results[i];
        let placemark = new WorldWind.Placemark(
          new WorldWind.Position(
            parseFloat(item.lat),
            parseFloat(item.lon), 100));
        placemark.altitudeMode = WorldWind.RELATIVE_TO_GROUND;
        placemark.displayName = item.display_name;
        placemark.attributes = placemarkAttributes;
        resultsLayer.addRenderable(placemark);
      }

      // Initialize preview with the first item
      self.previewSelection(results[0]);
      // Display the preview dialog
      $('#preview-dialog').modal();
      $('#preview-dialog .modal-body-table').scrollTop(0);
    };

    // Center's the preview globe on the selection and sets the selected item.
    this.previewSelection = function(selection) {
      let latitude = parseFloat(selection.lat),
        longitude = parseFloat(selection.lon),
        location = new WorldWind.Location(latitude, longitude);
      // Update our observable holding the selected location
      self.selected(location);
      // Go to the posiion
      self.previewGlobe.wwd.goTo(location);
    };

    // Centers the primary globe on the selected item
    this.gotoSelected = function() {
      // Go to the location held in the selected observable
      primaryGlobe.wwd.goTo(self.selected());
    };
  }

  // Create a globe
  let globe = new Globe("globe-canvas");
  // Add layers to the globe 
  // Add layers ordered by drawing order: first to last
  globe.addLayer(new WorldWind.BMNGLayer(), {
    category: "base"
  });
  globe.addLayer(new WorldWind.BMNGLandsatLayer(), {
    category: "base",
    enabled: false
  });
  globe.addLayer(new WorldWind.BingAerialLayer(), {
    category: "base",
    enabled: false
  });
  globe.addLayer(new WorldWind.BingAerialWithLabelsLayer(), {
    category: "base",
    enabled: false,
    detailControl: 1.5
  });
  globe.addLayer(new WorldWind.BingRoadsLayer(), {
    category: "overlay",
    enabled: false,
    detailControl: 1.5,
    opacity: 0.75
  });
  globe.addLayer(new WorldWind.CoordinatesDisplayLayer(globe.wwd), {
    category: "setting"
  });
  globe.addLayer(new WorldWind.ViewControlsLayer(globe.wwd), {
    category: "setting"
  });
  globe.addLayer(new WorldWind.CompassLayer(), {
    category: "setting",
    enabled: false
  });
  globe.addLayer(new WorldWind.StarFieldLayer(), {
    category: "setting",
    enabled: false,
    displayName: "Stars"
  });
  globe.addLayer(new WorldWind.AtmosphereLayer(), {
    category: "setting",
    enabled: true,
    time: null // or new Date()
  });

  var placemarkLayer = new WorldWind.RenderableLayer("Placemark");
  globe.addLayer(placemarkLayer);

  var placemarkAttributes = new WorldWind.PlacemarkAttributes(null);

  placemarkAttributes.imageOffset = new WorldWind.Offset(
    WorldWind.OFFSET_FRACTION, 0.3,
    WorldWind.OFFSET_FRACTION, 0.0);

  placemarkAttributes.labelAttributes.color = WorldWind.Color.YELLOW;
  placemarkAttributes.labelAttributes.offset = new WorldWind.Offset(
            WorldWind.OFFSET_FRACTION, 0.5,
            WorldWind.OFFSET_FRACTION, 1.0);

  // Create the custom image for the placemark with a 2D canvas.
  var canvas = document.createElement("canvas"),
  ctx2d = canvas.getContext("2d"),
  //size = 64, c = size / 2 - 0.5, innerRadius = 5, outerRadius = 20;
  size = 8, c = size / 2 - 0.5, innerRadius = 0, outerRadius = 4;

  canvas.width = size;
  canvas.height = size;

  
  var gradient = ctx2d.createRadialGradient(c, c, innerRadius, c, c, outerRadius);
  gradient.addColorStop(0, 'rgb(255, 255, 255)');
  gradient.addColorStop(1, 'rgb(255, 255, 255)');
  ctx2d.fillStyle = gradient;
  ctx2d.arc(c, c, outerRadius, 0, 2 * Math.PI, false);
  ctx2d.fill();

  
  // Set placemark attributes.
  var placemarkAttributes = new WorldWind.PlacemarkAttributes(null);
  // Wrap the canvas created above in an ImageSource object to specify it as the placemarkAttributes image source.
  placemarkAttributes.imageSource = new WorldWind.ImageSource(canvas);
  // Define the pivot point for the placemark at the center of its image source.
  placemarkAttributes.imageOffset = new WorldWind.Offset(WorldWind.OFFSET_FRACTION, 0.5, WorldWind.OFFSET_FRACTION, 0.5);
  placemarkAttributes.imageScale = 1;
  placemarkAttributes.imageColor = WorldWind.Color.WHITE;
  //placemarkAttributes.imageColor = WorldWind.Color.RED;

  // Set placemark highlight attributes.
  // Note that the normal attributes are specified as the default highlight attributes so that all properties
  // are identical except the image scale. You could instead vary the color, image, or other property
  // to control the highlight representation.
  var highlightAttributes = new WorldWind.PlacemarkAttributes(placemarkAttributes);
  highlightAttributes.imageScale = 1.2;
  //placemarkAttributes.imageScale = 5.0;
    //placemarkAttributes.imageSource = WorldWind.configuration.baseUrl + "dots/plain-red.png";

//  var position2 = new WorldWind.Position(0.119, 70.155, 3003847.326);
//  var placemark2 = new WorldWind.Placemark(position2, false, placemarkAttributes);
//  placemark2.alwaysOnTop = true;
//  placemarkLayer.addRenderable(placemark2);

//  var position3 = new WorldWind.Position(-0.121, 57.229, 1808966.641);
//  var placemark3 = new WorldWind.Placemark(position3, false, placemarkAttributes);
//  placemark3.alwaysOnTop = true;
//  placemarkLayer.addRenderable(placemark3);

 // var position4 = new WorldWind.Position(0.100, -154.877, 2460210.929);
//  var placemark4 = new WorldWind.Placemark(position4, false, placemarkAttributes);
//  placemark4.alwaysOnTop = true;
    //  placemarkLayer.addRenderable(placemark4);
    // Sample TLE
//    var tleLine1 = '1 25544U 98067A   13149.87225694  .00009369  00000-0  16828-3 0  9031',
    //	tleLine2 = '2 25544 051.6485 199.1576 0010128 012.7275 352.5669 15.50581403831869';
  //var tleLine1 = '1 25544U 98067A   13149.87225694  .00009369  00000-0  16828-3 0  9031',
//	tleLine2 = '2 25544 051.6485 199.1576 0010128 012.7275 352.5669 15.50581403831869';
    

   // var spaceDebris =  ["1 24946U 97051C   18072.81969124  .00000077  00000-0  20774-4 0  9993",
    //			"2 24946  86.3936 173.9133 0010038  87.3628 272.8716 14.33594224 72655" ];
    
 //   var spaceDebris = ["1 24946U 97051C   18072.81969124  .00000077  00000-0  20774-4 0  9993",
//		       "2 24946  86.3936 173.9133 0010038  87.3628 272.8716 14.33594224 72655",
//		       "1 33772U 97051K   18072.79683295  .00006758  00000-0  80789-3 0  9992",
//		       "2 33772  86.4100 161.1852 0024359 235.6413 246.4187 14.83834582479181",
//		       "1 33773U 97051L   18072.81928343  .00000199  00000-0  58735-4 0  9992",
//		       "2 33773  86.4081 172.1791 0013748 106.9150 253.3557 14.38225248476269",
//		       "1 33775U 97051N   18072.82675394  .00000172  00000-0  53596-4 0  9991",
//		       "2 33775  86.3736 167.0559 0016851  81.4877  41.0967 14.34896063475073",
//		       "1 33850U 97051T   18072.75474943  .00000091  00000-0  24507-4 0  9994",
//		       "2 33850  86.3487 156.6556 0014655  86.7090  28.1147 14.35563758474894",
//		       "1 33853U 97051W   18072.63418771  .00000163  00000-0  92440-4 0  9992",
//		       "2 33853  86.0051 136.7341 0242814 187.2506 298.4677 13.90147916459551",
//		       "1 33854U 97051X   18072.96392431  .00001609  00000-0  29754-3 0  9996",
//		       "2 33854  86.2245  72.3941 0007530 325.6051  91.8181 14.64773909480555",
//		       "1 33855U 97051Y   18072.86300254  .00009244  00000-0  19527-2 0  9997",
//		       "2 33855  86.3364 205.9902 0013484 315.7504  44.2626 14.59211576296156",
//		       "1 33858U 97051AB  18072.91604334  .00004946  00000-0  44078-3 0  9996",
//		       "2 33858  86.1328  18.2621 0020324  75.5347 349.1311 14.95642690483158",
//		       "1 33859U 97051AC  18072.76015279  .00000873  00000-0  26485-3 0  9991",
//		       "2 33859  86.3474 160.2228 0050620 101.1806 259.5089 14.40339968474463",
//		       "1 33860U 97051AD  18072.31650716  .00000542  00000-0  15112-3 0  9993",
//		       "2 33860  86.3976 162.1440 0016376  77.7189 349.4992 14.44425346477073",
//		       "1 40996U 97051ABJ 18072.52299948  .00000641  00000-0  17206-3 0  9996",
//		       "2 40996  86.3780 155.6695 0010573 238.1344 179.5816 14.46599104213017",
//		       "1 40997U 97051ABK 18069.86188188  .00006915  00000-0  70817-3 0  9990",
//		       "2 40997  86.3589 126.5497 0014382  77.2648 283.0186 14.90280955353457",
//		       "1 40998U 97051ABL 18070.54859090  .00000252  00000-0  78007-4 0  9993",
//		       "2 40998  86.3930 171.0089 0009234  38.9873  19.5640 14.37109208663626"];
    
    var spaceDebris = ["1 24946U 97051C   18072.81969124  .00000077  00000-0  20774-4 0  9993",
		       "2 24946  86.3936 173.9133 0010038  87.3628 272.8716 14.33594224 72655",
		       "1 33772U 97051K   18072.79683295  .00006758  00000-0  80789-3 0  9992",
		       "2 33772  86.4100 161.1852 0024359 235.6413 246.4187 14.83834582479181",
		       "1 33773U 97051L   18072.81928343  .00000199  00000-0  58735-4 0  9992",
		       "2 33773  86.4081 172.1791 0013748 106.9150 253.3557 14.38225248476269",
		       "1 33775U 97051N   18072.82675394  .00000172  00000-0  53596-4 0  9991",
		       "2 33775  86.3736 167.0559 0016851  81.4877  41.0967 14.34896063475073",
		       "1 33776U 97051P   18072.88244383  .00000104  00000-0  30161-4 0  9996",
		       "2 33776  86.4119 182.5536 0017063  87.9100  37.3201 14.33820651474935",
		       "1 33777U 97051Q   18072.78576497  .00000707  00000-0  21257-3 0  9994",
		       "2 33777  86.3904 163.1530 0008949 276.4491  83.5689 14.41336447476587",
		       "1 33849U 97051S   18072.78507871  .00002654  00000-0  71400-3 0  9992",
		       "2 33849  86.1012  87.1295 0063611 253.9295 105.4896 14.46496881472468",
		       "1 33850U 97051T   18072.75474943  .00000091  00000-0  24507-4 0  9994",
		       "2 33850  86.3487 156.6556 0014655  86.7090  28.1147 14.35563758474894",
		       "1 33853U 97051W   18072.63418771  .00000163  00000-0  92440-4 0  9992",
		       "2 33853  86.0051 136.7341 0242814 187.2506 298.4677 13.90147916459551",
		       "1 33854U 97051X   18072.96392431  .00001609  00000-0  29754-3 0  9996",
		       "2 33854  86.2245  72.3941 0007530 325.6051  91.8181 14.64773909480555",
		       "1 33855U 97051Y   18072.86300254  .00009244  00000-0  19527-2 0  9997",
		       "2 33855  86.3364 205.9902 0013484 315.7504  44.2626 14.59211576296156",
		       "1 33858U 97051AB  18072.91604334  .00004946  00000-0  44078-3 0  9996",
		       "2 33858  86.1328  18.2621 0020324  75.5347 349.1311 14.95642690483158",
		       "1 33859U 97051AC  18072.76015279  .00000873  00000-0  26485-3 0  9991",
		       "2 33859  86.3474 160.2228 0050620 101.1806 259.5089 14.40339968474463",
		       "1 33860U 97051AD  18072.31650716  .00000542  00000-0  15112-3 0  9993",
		       "2 33860  86.3976 162.1440 0016376  77.7189 349.4992 14.44425346477073",
		       "1 33862U 97051AF  18072.80949809  .00000462  00000-0  12179-3 0  9994",
		       "2 33862  86.4196 167.9596 0056690 198.7043 284.4674 14.45822267477711",
		       "1 33864U 97051AH  18072.83753363  .00001192  00000-0  30520-3 0  9998",
		       "2 33864  86.2761 115.1064 0004887 163.0687 249.9855 14.49618893477498",
		       "1 33865U 97051AJ  18072.90575253  .00002283  00000-0  42779-3 0  9998",
		       "2 33865  86.3485 133.5907 0035092 296.4948 122.1199 14.63998414478957",
		       "1 33866U 97051AK  18072.81192417  .00000333  00000-0  15379-3 0  9996",
		       "2 33866  86.3037 192.8419 0131418 125.5747 358.9380 14.13351597467370",
		       "1 33867U 97051AL  18072.75107598  .00000814  00000-0  17957-3 0  9994",
		       "2 33867  86.4208 153.5440 0031863  27.8863 332.4044 14.55829852479980",
		       "1 33869U 97051AN  18072.79464578  .00001157  00000-0  35015-3 0  9990",
		       "2 33869  86.3663 186.2009 0073283 198.6260 161.2255 14.39990547472369",
		       "1 33870U 97051AP  18072.79001433  .00000394  00000-0  13104-3 0  9996",
		       "2 33870  86.3856 174.1345 0025826 110.0594   7.6324 14.34989701474617",
		       "1 33873U 97051AS  18072.73911135  .00000748  00000-0  16249-3 0  9998",
		       "2 33873  86.3692 141.6176 0023162  18.8835 341.3227 14.56600459478509",
		       "1 33874U 97051AT  18072.78658362  .00001361  00000-0  49062-3 0  9995",
		       "2 33874  86.2937 163.0550 0076204 279.8894 205.6244 14.31430585471355",
		       "1 33875U 97051AU  18072.94444625  .00001407  00000-0  23353-3 0  9995",
		       "2 33875  86.4094 132.4547 0031062 218.8606 261.9492 14.69147050482585",
		       "1 33876U 97051AV  18072.96759771  .00004563  00000-0  58179-3 0  9999",
		       "2 33876  86.1969  61.7939 0008367 182.1509 229.2842 14.81275406481036",
		       "1 33878U 97051AX  18072.73161682  .00003981  00000-0  11687-2 0  9999",
		       "2 33878  86.3150 172.4321 0107463 233.0930 126.0386 14.40278429471655",
		       "1 33879U 97051AY  18072.63144058  .00003671  00000-0  58923-3 0  9998",
		       "2 33879  86.3611 125.1500 0025413 203.9383 156.0653 14.71191440229386",
		       "1 33881U 97051BA  18072.84779021  .00000706  00000-0  28694-3 0  9996",
		       "2 33881  86.3928 208.7855 0082910   4.6135 115.1857 14.24416436469850",
		       "1 33884U 97051BD  18072.72229951  .00000333  00000-0  87217-4 0  9991",
		       "2 33884  86.3857 155.7534 0014496 156.7558 322.1928 14.46259874477483",
		       "1 33886U 97051BF  18072.86409670  .00000117  00000-0  35209-4 0  9990",
		       "2 33886  86.3900 174.1289 0016521 114.9334  20.6922 14.33286941474847",
		       "1 33887U 97051BG  18072.69063317  .00000096  00000-0  26719-4 0  9998",
		       "2 33887  86.3067 139.3142 0008662 118.5748   4.4708 14.34956283475431",
		       "1 33888U 97051BH  18072.71203567  .00001462  00000-0  44691-3 0  9991",
		       "2 33888  86.3286 158.5270 0052149 133.4984 227.0569 14.40435442473798",
		       "1 33950U 97051BK  18072.91305290  .00002205  00000-0  45268-3 0  9996",
		       "2 33950  86.3860 151.0861 0014010 239.5236 120.4591 14.60204595478266",
		       "1 33952U 97051BM  18072.62579880  .00001720  00000-0  38970-3 0  9997",
		       "2 33952  86.3535 139.1468 0011719 346.4454  13.6437 14.55557086478442",
		       "1 33953U 97051BN  18072.26281185  .00000551  00000-0  17353-3 0  9999",
		       "2 33953  86.3984 174.7499 0025528  95.9368 293.7131 14.38447305474860",
		       "1 33954U 97051BP  18072.54342656  .00002491  00000-0  54609-3 0  9992",
		       "2 33954  86.3827 159.7101 0017068 216.9265 206.0812 14.57212400477202",
		       "1 33955U 97051BQ  18072.75350092  .00003953  00000-0  71533-3 0  9998",
		       "2 33955  86.3608 155.4233 0036607 331.4110  28.5095 14.65703272476975",
		       "1 33956U 97051BR  18072.77011307  .00003905  00000-0  60719-3 0  9995",
		       "2 33956  86.4189 164.7027 0035559 101.2589  21.7366 14.72365817229006",
		       "1 33959U 97051BU  18072.86018602  .00001143  00000-0  40045-3 0  9995",
		       "2 33959  86.3625 187.2920 0069797 243.3333 116.0703 14.32956955471277",
		       "1 33960U 97051BV  18072.86025640  .00000231  00000-0  58511-4 0  9992",
		       "2 33960  86.2736 114.3156 0002298 280.8383 205.2519 14.46589952477419",
		       "1 33961U 97051BW  18072.91089769  .00002590  00000-0  49038-3 0  9994",
		       "2 33961  86.2686 105.3221 0018055 303.2488  56.6993 14.63888289478768",
		       "1 33962U 97051BX  18072.86079194  .00001715  00000-0  34221-3 0  9996",
		       "2 33962  86.3538 136.5698 0012970 325.2030  34.8332 14.61367206478828",
		       "1 33964U 97051BZ  18072.75777837  .00091811  00000-0  19852-2 0  9993",
		       "2 33964  86.3008  78.9473 0008920 122.9190 237.2925 15.44110578485680",
		       "1 33965U 97051CA  18072.68870602  .00001038  00000-0  25976-3 0  9997",
		       "2 33965  86.3737 151.3631 0006456 341.9896  18.1079 14.50576865477341",
		       "1 33966U 97051CB  18072.77244267  .00000358  00000-0  10633-3 0  9998",
		       "2 33966  86.4013 166.3029 0007869 195.9537 289.5591 14.40525872476483",
		       "1 33967U 97051CC  18072.74854338  .00001669  00000-0  32680-3 0  9994",
		       "2 33967  86.3823 148.6900 0041226 266.6988  92.9506 14.61706561478960",
		       "1 34071U 97051CE  18072.76376940  .00000348  00000-0  10575-3 0  9993",
		       "2 34071  86.3525 151.8658 0010363  96.4309 263.8070 14.39312426475416",
		       "1 34076U 97051CK  18072.82874052  .00003818  00000-0  46580-3 0  9992",
		       "2 34076  86.3307  94.3807 0037337 160.9418 253.5711 14.82574997482994",
		       "1 34077U 97051CL  18072.82157785  .00000474  00000-0  14609-3 0  9992",
		       "2 34077  86.4005 176.3838 0019652  62.4052  55.3197 14.39242610474494",
		       "1 34079U 97051CN  18072.69603226  .00000804  00000-0  20911-3 0  9995",
		       "2 34079  86.3951 156.4675 0012691 143.8515 346.5226 14.48399891477964",
		       "1 34081U 97051CQ  18072.74383278  .00008597  00000-0  55248-3 0  9994",
		       "2 34081  86.3135  72.6630 0022956 123.8870   2.2491 15.08066176485219",
		       "1 34082U 97051CR  18072.81733182  .00002884  00000-0  72069-3 0  9999",
		       "2 34082  86.3687 207.6769 0132568  12.4240 348.0176 14.46002913469987",
		       "1 34086U 97051CV  18072.29605644  .00000968  00000-0  28561-3 0  9995",
		       "2 34086  86.3907 176.6354 0025483  89.0588 323.7709 14.42420983474663",
		       "1 34088U 97051CX  18072.84610123  .00000820  00000-0  23153-3 0  9995",
		       "2 34088  86.4082 170.1317 0011267  51.2526  88.2290 14.44519176476267",
		       "1 34090U 97051CZ  18072.90700958  .00004245  00000-0  48145-3 0  9994",
		       "2 34090  86.4159 130.3244 0018708 193.2102 166.8635 14.85995960482847",
		       "1 34091U 97051DA  18072.84613083  .00000881  00000-0  32621-3 0  9994",
		       "2 34091  86.3746 191.5230 0063148 266.3293 224.2052 14.30215515471519",
		       "1 34093U 97051DC  18072.49071737  .00005653  00000-0  44354-3 0  9999",
		       "2 34093  86.2917  63.7713 0019326  38.3126  91.1105 15.00605945485655",
		       "1 34095U 97051DE  18072.76634953  .00001730  00000-0  38437-3 0  9993",
		       "2 34095  86.3870 163.4334 0047013   9.1195 351.0856 14.55787402476153",
		       "1 34097U 97051DG  18072.69388986  .00000791  00000-0  34929-3 0  9997",
		       "2 34097  86.2076 145.7312 0100549  54.3070 306.7424 14.19331313469144",
		       "1 34098U 97051DH  18072.94085565  .00003174  00000-0  45982-3 0  9992",
		       "2 34098  86.1357  32.0532 0015804 218.5862 201.9543 14.75711326481038",
		       "1 34099U 97051DJ  18072.70253132  .00002128  00000-0  44900-3 0  9991",
		       "2 34099  86.3679 146.8112 0011380 246.6840 237.6014 14.58949473478053",
		       "1 34101U 97051DL  18072.87774806  .00002571  00000-0  82825-3 0  9999",
		       "2 34101  86.3795 208.9639 0111619   1.0973 359.0446 14.35414770469371",
		       "1 34102U 97051DM  18072.91555701  .00001019  00000-0  40251-3 0  9999",
		       "2 34102  86.3803 220.9752 0115414  86.0471  32.0298 14.24455134467777",
		       "1 34103U 97051DN  18072.75088034  .00002268  00000-0  52482-3 0  9998",
		       "2 34103  86.3484 145.6928 0030773 203.2322 279.4369 14.54469679477075",
		       "1 34104U 97051DP  18072.92012493  .00002288  00000-0  38880-3 0  9992",
		       "2 34104  86.3424 118.4325 0024229  24.1864  29.4564 14.68547158480538",
		       "1 34105U 97051DQ  18072.87069044  .00006271  00000-0  62938-3 0  9998",
		       "2 34105  86.3466 117.0861 0010758  59.3534 300.8752 14.91112991481424",
		       "1 34106U 97051DR  18072.72483495  .00001164  00000-0  29040-3 0  9996",
		       "2 34106  86.3648 144.1958 0018849 135.6218 345.7968 14.50712253477874",
		       "1 34107U 97051DS  18072.74064559  .00000103  00000-0  19602-4 0  9991",
		       "2 34107  86.3891 151.2049 0018153 125.9794   1.9572 14.53080207478002",
		       "1 34143U 97051DW  18072.96551191  .00001536  00000-0  31197-3 0  9991",
		       "2 34143  86.3950 153.2826 0005234 218.7479 267.5557 14.60544337477807",
		       "1 34145U 97051DY  18072.88806388  .00000550  00000-0  20954-3 0  9999",
		       "2 34145  86.2185 129.7032 0061414 271.3059  88.1098 14.28178840471331",
		       "1 34146U 97051DZ  18072.87582932  .00000338  00000-0  10863-3 0  9997",
		       "2 34146  86.2909 138.4929 0040537 144.0730 268.1794 14.35853621473939",
		       "1 34147U 97051EA  18072.76051856  .00006224  00000-0  85972-3 0  9995",
		       "2 34147  86.4401 185.9734 0058569 342.7148  17.2075 14.76775574477433",
		       "1 34148U 97051EB  18072.64188732  .00009517  00000-0  73400-3 0  9998",
		       "2 34148  86.3905 129.4095 0010353 182.3696 177.7489 15.01442276482076",
		       "1 34150U 97051ED  18072.85479014  .00003327  00000-0  72152-3 0  9996",
		       "2 34150  86.4849 212.7687 0087563  90.9551  33.6216 14.55464608474879",
		       "1 34155U 97051EJ  18072.85553229  .00001745  00000-0  35029-3 0  9996",
		       "2 34155  86.4707 193.8187 0050050 295.6922 188.9440 14.60358617477030",
		       "1 34159U 97051EN  18072.74618601  .00000224  00000-0  74775-4 0  9997",
		       "2 34159  86.3585 165.8632 0032677 155.1485 205.1292 14.32687900473818",
		       "1 34160U 97051EP  18072.75721514  .00001206  00000-0  26271-3 0  9996",
		       "2 34160  86.4118 174.4571 0031032  49.8353 310.5565 14.56834856475881",
		       "1 34350U 97051ES  18072.92982903  .00000123  00000-0  32849-4 0  9993",
		       "2 34350  86.3316 141.2948 0024828 107.0508  20.0897 14.39460579475277",
		       "1 34351U 97051ET  18072.72802172  .00001922  00000-0  38142-3 0  9990",
		       "2 34351  86.4267 159.6915 0038636 281.6917  77.9960 14.61246169478497",
		       "1 34354U 97051EW  18072.45493001  .00004452  00000-0  59934-3 0  9993",
		       "2 34354  86.2077  74.9317 0030679 118.0504 242.3825 14.78671009479319",
		       "1 34358U 97051FA  18072.93169865  .00000636  00000-0  15773-3 0  9991",
		       "2 34358  86.3279 137.6408 0006438  14.9374  43.7151 14.50344863476453",
		       "1 34359U 97051FB  18072.89667663  .00002859  00000-0  45090-3 0  9990",
		       "2 34359  86.3582 127.2079 0035472  57.3541   6.7672 14.71648311479466",
		       "1 34361U 97051FD  18072.92421163  .00006424  00000-0  71130-3 0  9996",
		       "2 34361  86.3544 133.9738 0023336 155.7427 204.4903 14.86984275478747",
		       "1 34363U 97051FF  18072.75887369  .00003154  00000-0  77938-3 0  9992",
		       "2 34363  86.3549 161.0444 0045873  94.7861  26.4940 14.51146004474240",
		       "1 34366U 97051FJ  18072.79617727  .00000406  00000-0  13068-3 0  9999",
		       "2 34366  86.3819 172.3102 0030135 123.6544 359.0841 14.36572675474205",
		       "1 34367U 97051FK  18072.77781351  .00002506  00000-0  54183-3 0  9999",
		       "2 34367  86.4188 173.7129 0023627 338.0688 140.1707 14.57774005476520",
		       "1 34368U 97051FL  18072.86174144  .00004094  00000-0  98533-3 0  9997",
		       "2 34368  86.3883 185.1365 0077909 142.6249   3.9738 14.51225130472963",
		       "1 34375U 97051FT  18072.93735808  .00000239  00000-0  11017-3 0  9992",
		       "2 34375  86.4309 237.6836 0109962  75.2924  45.6312 14.13348691466912",
		       "1 34376U 97051FU  18072.71724156  .00000545  00000-0  18060-3 0  9998",
		       "2 34376  86.3153 153.6782 0040788 152.2112 208.1276 14.35559258473809",
		       "1 34378U 97051FW  18072.76342798  .00003852  00000-0  97700-3 0  9995",
		       "2 34378  86.3555 172.9635 0060092 139.3418 221.2296 14.49513780472704",
		       "1 34486U 97051GB  18072.23935028  .00000694  00000-0  17073-3 0  9997",
		       "2 34486  86.4165 160.1223 0018794  29.4004  22.2090 14.50787515477668",
		       "1 34487U 97051GC  18072.47771156  .00000145  00000-0  39606-4 0  9992",
		       "2 34487  86.3495 145.4092 0034678  97.2822 319.8488 14.39780539475013",
		       "1 34488U 97051GD  18072.91360548  .00000892  00000-0  20527-3 0  9991",
		       "2 34488  86.3467 128.2151 0024169 355.7580   4.3418 14.54165080477886",
		       "1 34489U 97051GE  18072.59485009  .00002094  00000-0  67619-3 0  9995",
		       "2 34489  86.4157 210.2268 0080821 244.6252 114.6562 14.36895234470355",
		       "1 34490U 97051GF  18072.91945236  .00005635  00000-0  76516-3 0  9996",
		       "2 34490  86.3256 122.1360 0047042 172.9853 239.0156 14.77902777478320",
		       "1 34492U 97051GH  18072.74920494  .00002370  00000-0  13806-2 0  9993",
		       "2 34492  86.5011 337.5571 0313703 288.3458 123.6434 13.86456489455754",
		       "1 34493U 97051GJ  18072.51091200  .00002351  00000-0  44720-3 0  9992",
		       "2 34493  86.2662 108.3801 0057188 206.9281 152.8961 14.62651766475836",
		       "1 34496U 97051GM  18072.13154930  .00003131  00000-0  97287-3 0  9996",
		       "2 34496  86.3892 212.6886 0083069 340.5164  19.2864 14.38809425468828",
		       "1 34497U 97051GN  18072.56503566  .00000258  00000-0  10823-3 0  9995",
		       "2 34497  86.2871 169.4175 0090577  20.9265  43.9889 14.19740894466550",
		       "1 34503U 97051GU  18072.58762446  .00000695  00000-0  14819-3 0  9993",
		       "2 34503  86.3166 110.5965 0006886  95.7088 264.4906 14.57515242478847",
		       "1 34508U 97051GZ  18072.83809154  .00000436  00000-0  17683-3 0  9999",
		       "2 34508  86.3826 200.0260 0076485 307.4722  51.9528 14.23961175469187",
		       "1 34511U 97051HC  18072.80934674  .00001231  00000-0  33107-3 0  9999",
		       "2 34511  86.3930 169.6947 0025014  34.9421  91.8710 14.47126345474583",
		       "1 34517U 97051HJ  18072.93534816  .00002676  00000-0  39632-3 0  9996",
		       "2 34517  86.3653 131.7589 0008817  85.4084  35.7546 14.74767830478567",
		       "1 34518U 97051HK  18072.92010407  .00003281  00000-0  50343-3 0  9996",
		       "2 34518  86.3967 148.1589 0009466 281.2269  78.7884 14.73307559478075",
		       "1 34520U 97051HM  18072.92865252  .00004768  00000-0  66124-3 0  9990",
		       "2 34520  86.3657 138.9766 0016311 194.2430 165.8332 14.77677490477880",
		       "1 34521U 97051HN  18072.75927382  .00000913  00000-0  26900-3 0  9991",
		       "2 34521  86.3918 163.1878 0005218  10.0872 106.4551 14.42618952475202",
		       "1 34522U 97051HP  18072.78540566  .00004156  00000-0  91608-3 0  9990",
		       "2 34522  86.3656 170.1758 0049526 101.6830  16.1934 14.56413222473666",
		       "1 34524U 97051HR  18072.65756203  .00000160  00000-0  36184-4 0  9995",
		       "2 34524  86.3488 150.6077 0034632  50.2431 310.1815 14.49166843474972",
		       "1 34525U 97051HS  18072.77613668  .00000227  00000-0  70239-4 0  9999",
		       "2 34525  86.3810 165.2503 0005461  46.4788  77.6278 14.36856576473925",
		       "1 34526U 97051HT  18072.89289490  .00003264  00000-0  54986-3 0  9999",
		       "2 34526  86.3444 136.5337 0015900 241.5074 171.4975 14.69183192477104",
		       "1 34529U 97051HW  18072.74552686  .00000090  00000-0  23255-4 0  9996",
		       "2 34529  86.3702 157.2046 0009771 129.1001 231.1067 14.37739545475008",
		       "1 34532U 97051HZ  18072.71444480  .00004107  00000-0  82712-3 0  9994",
		       "2 34532  86.3396 157.6811 0040103  48.7492 311.7161 14.60816477473823",
		       "1 34535U 97051JC  18072.86581598  .00003473  00000-0  50480-3 0  9997",
		       "2 34535  86.3327 111.7496 0017067 172.4399 241.3416 14.75585865480160",
		       "1 34538U 97051JF  18072.65252120  .00000292  00000-0  10303-3 0  9999",
		       "2 34538  86.2841 146.3196 0044339 171.7651 315.9610 14.30759798471904",
		       "1 34540U 97051JH  18072.64049458  .00000796  00000-0  19234-3 0  9990",
		       "2 34540  86.3217 120.3116 0028257  27.7092  93.4886 14.51673227478443",
		       "1 34593U 97051JK  18072.89460628  .00029717  00000-0  12994-2 0  9990",
		       "2 34593  86.3367 125.0758 0002608  53.3507   4.2342 15.21943624481023",
		       "1 34643U 97051JU  18072.70371274  .00001298  00000-0  31853-3 0  9994",
		       "2 34643  86.3882 162.2516 0032154  30.9084 329.4005 14.51368886472926",
		       "1 34648U 97051JZ  18072.91922729  .00001145  00000-0  80067-3 0  9991",
		       "2 34648  86.4098 302.6796 0237490 284.0937 131.2075 13.85171839455855",
		       "1 34651U 97051KC  18071.83040824  .00000874  00000-0  49028-3 0  9992",
		       "2 34651  86.2962 226.8216 0191613  33.0651 328.2334 14.00654901460713",
		       "1 34652U 97051KD  18072.48058146  .00000497  00000-0  13220-3 0  9997",
		       "2 34652  86.3376 134.2720 0038998  42.7689  14.2026 14.46081121475332",
		       "1 34690U 97051KM  18072.77060837  .00000949  00000-0  28295-3 0  9991",
		       "2 34690  86.3904 166.2473 0010812  77.9249  52.3665 14.42025372471967",
		       "1 34693U 97051KQ  18072.92735163  .00000897  00000-0  21028-3 0  9991",
		       "2 34693  86.3390 127.3226 0025066 356.3526 123.9411 14.53291726474880",
		       "1 34696U 97051KT  18072.29078764  .00001281  00000-0  61084-3 0  9995",
		       "2 34696  86.2121 172.9866 0152112 225.3278 197.7899 14.12696749463934",
		       "1 34702U 97051KZ  18072.80196168  .00000904  00000-0  18425-3 0  9991",
		       "2 34702  86.3061 103.0937 0039392 269.8507  89.8189 14.59419528478468",
		       "1 34705U 97051LC  18072.31133786  .00003209  00000-0  59035-3 0  9990",
		       "2 34705  86.4706 198.2149 0066779 327.9919  31.7244 14.63888709475170",
		       "1 34706U 97051LD  18072.80467683  .00003560  00000-0  39078-3 0  9996",
		       "2 34706  86.3157  90.0979 0029946 193.1959 291.4102 14.87071738480550",
		       "1 34764U 97051LH  18072.16840194  .00004089  00000-0  53314-3 0  9997",
		       "2 34764  86.3613 128.3414 0009396 114.5497 245.6704 14.80310260477881",
		       "1 34765U 97051LJ  18072.75553608  .00000241  00000-0  78635-4 0  9994",
		       "2 34765  86.3455 157.6991 0020161 113.3663  15.6578 14.34321583469880",
		       "1 34773U 97051LS  18072.25714729  .00001400  00000-0  34704-3 0  9997",
		       "2 34773  86.4166 170.4396 0013945 278.5826  81.3799 14.51235659476440",
		       "1 34774U 97051LT  18072.76144403  .00000413  00000-0  86830-4 0  9991",
		       "2 34774  86.4319 168.1493 0018653 188.1451 296.9629 14.56973713478234",
		       "1 34775U 97051LU  18072.54717858  .00000882  00000-0  25964-3 0  9998",
		       "2 34775  86.3843 170.8586 0032781  61.7585 357.1531 14.42284612472055",
		       "1 34825U 97051LZ  18072.53669249  .00001459  00000-0  35517-3 0  9999",
		       "2 34825  86.3761 155.0032 0009152 313.4687 110.0164 14.52128048472887",
		       "1 34827U 97051MB  18072.16229843  .00002764  00000-0  40146-3 0  9996",
		       "2 34827  86.3829 139.6908 0024771 329.0371  60.5573 14.75428831475740",
		       "1 34833U 97051MH  18072.73278493  .00000372  00000-0  11202-3 0  9995",
		       "2 34833  86.4024 170.7208 0025604  98.7353  27.0486 14.39662150468950",
		       "1 34868U 97051MN  18072.21377080  .00002644  00000-0  60033-3 0  9998",
		       "2 34868  86.5398 236.5985 0126116 130.7602 230.4633 14.50792556469110",
		       "1 34869U 97051MP  18072.68281340  .00002351  00000-0  73603-3 0  9995",
		       "2 34869  86.4577 221.5235 0073216 207.6676 209.4518 14.38773758464851",
		       "1 34870U 97051MQ  18072.11930014  .00000636  00000-0  16019-3 0  9996",
		       "2 34870  86.3206 124.6941 0031523  26.6151   4.0572 14.49281870477315",
		       "1 34889U 97051MR  18072.47962867  .00002144  00000-0  42508-3 0  9994",
		       "2 34889  86.3723 144.9727 0008486 201.6309 158.4545 14.61812825472401",
		       "1 34890U 97051MS  18072.48343349  .00002650  00000-0  72623-3 0  9998",
		       "2 34890  86.3071 159.8326 0080831 166.3033 194.0389 14.44868273467263",
		       "1 34893U 97051MV  18072.89756094  .00051051  00000-0  20808-2 0  9997",
		       "2 34893  86.1012  40.5173 0021003 169.7740 190.3936 15.24044052480120",
		       "1 34896U 97051MY  18072.91794181  .00000507  00000-0  12728-3 0  9995",
		       "2 34896  86.3352 127.4726 0037025  15.2734 106.0872 14.48962531465133",
		       "1 34898U 97051NA  18072.10436584  .00001303  00000-0  23418-3 0  9991",
		       "2 34898  86.3310 108.2335 0022244 244.3814 115.5101 14.65757830474215",
		       "1 34899U 97051NB  18072.51277955  .00004323  00000-0  66671-3 0  9995",
		       "2 34899  86.3997 157.8268 0022820 275.9207 140.6279 14.73013541469939",
		       "1 34926U 97051NF  18071.19956059  .00000348  00000-0  16519-3 0  9997",
		       "2 34926  86.1627 163.3021 0169642 289.8390  95.9430 14.09749689462750",
		       "1 34928U 97051NH  18072.91170287  .00000760  00000-0  16198-3 0  9992",
		       "2 34928  86.4054 143.8156 0030366 337.0267  22.9582 14.57377281247005",
		       "1 34983U 97051NP  18071.54878565  .00003555  00000-0  66732-3 0  9999",
		       "2 34983  86.3624 155.2992 0030940 326.5204  33.4051 14.64164660468461",
		       "1 34985U 97051NR  18072.05399601  .00000246  00000-0  80792-4 0  9994",
		       "2 34985  86.3775 172.2026 0026202 127.9484 356.7003 14.33992874465339",
		       "1 34986U 97051NS  18072.22426541  .00001518  00000-0  38325-3 0  9995",
		       "2 34986  86.3885 167.8882 0025428  30.9800 329.2898 14.50260737466878",
		       "1 34987U 97051NT  18072.85277961  .00002305  00000-0  31858-3 0  9994",
		       "2 34987  86.3363 108.8255 0004954 235.9431 124.1319 14.77677573480603",
		       "1 35049U 97051NV  18072.47957018  .00001554  00000-0  32946-3 0  9994",
		       "2 35049  86.3747 141.4754 0024883 116.2937 244.0832 14.58369652302544",
		       "1 35050U 97051NW  18072.06883457  .00002179  00000-0  30692-3 0  9996",
		       "2 35050  86.3082 108.3135 0024334 213.1087 146.8611 14.76633339470363",
		       "1 35051U 97051NX  18072.46995016  .00000373  00000-0  11740-3 0  9993",
		       "2 35051  86.3299 147.0638 0010455  57.9909 302.2304 14.37700305462451",
		       "1 35052U 97051NY  18072.55696942  .00000137  00000-0  40848-4 0  9990",
		       "2 35052  86.3351 149.1934 0011095 351.6982  74.7461 14.35475768466379",
		       "1 35054U 97051PA  18072.87913759  .00004744  00000-0  70471-3 0  9997",
		       "2 35054  86.3447 129.4607 0012500 192.0079 168.0844 14.74780785471460",
		       "1 35077U 97051PC  18070.82345985  .00006433  00000-0  62243-3 0  9990",
		       "2 35077  86.2772  92.7256 0049465 138.1457 222.3570 14.91659667470842",
		       "1 35078U 97051PD  18068.88702346  .00032340  00000-0  12749-2 0  9993",
		       "2 35078  86.3607 124.5289 0007689  81.0349 258.8331 15.25410236470393",
		       "1 35079U 97051PE  18071.23047430  .00001690  00000-0  73733-3 0  9998",
		       "2 35079  86.4296 248.2999 0155705 198.2066 161.3510 14.17109863458856",
		       "1 35080U 97051PF  18072.61556303  .00001689  00000-0  77940-3 0  9999",
		       "2 35080  86.2440 192.6766 0182406 275.3737  82.6661 14.12149497457810",
		       "1 35293U 97051PH  18072.27926404  .00006591  00000-0  48728-3 0  9999",
		       "2 35293  86.3063  70.4665 0017830 348.6766  11.4063 15.02912929474580",
		       "1 35294U 97051PJ  18072.93492222  .00001672  00000-0  38006-3 0  9992",
		       "2 35294  86.3281 131.4327 0010983 322.4254 158.2744 14.55410087465233",
		       "1 35296U 97051PL  18072.90036876  .00001522  00000-0  38864-3 0  9996",
		       "2 35296  86.3126 129.4951 0010504 342.2048  17.8787 14.49902690299380",
		       "1 35297U 97051PM  18072.62302181  .00000359  00000-0  11741-3 0  9993",
		       "2 35297  86.3960 175.8380 0019032  79.4802 347.7664 14.35668638297372",
		       "1 35299U 97051PP  18072.22227925  .00000374  00000-0  14417-3 0  9993",
		       "2 35299  86.2994 163.0260 0063020 269.4310 119.3919 14.26707591458554",
		       "1 35477U 97051PX  18065.13734858  .00002731  00000-0  86659-3 0  9997",
		       "2 35477  86.3759 212.1855 0093085  20.1452 340.3379 14.37219833457599",
		       "1 35478U 97051PY  18070.07727521  .00005814  00000-0  98425-3 0  9995",
		       "2 35478  86.4507 197.5920 0057192  65.9171 294.8012 14.68070146197409",
		       "1 35479U 97051PZ  18072.69117108  .00002892  00000-0  10996-2 0  9999",
		       "2 35479  86.3935 215.1164 0107653  47.2793 313.7400 14.27511070453994",
		       "1 35480U 97051QA  18071.50730199  .00000121  00000-0  32230-4 0  9991",
		       "2 35480  86.3655 156.3032 0018887  98.9811 261.3527 14.39587861462115",
		       "1 35483U 97051QD  18072.06375644  .00004543  00000-0  12491-2 0  9993",
		       "2 35483  86.4342 202.4324 0051580 146.0913 214.3606 14.46012340462865",
		       "1 35484U 97051QE  18071.47285389  .00000607  00000-0  15094-3 0  9994",
		       "2 35484  86.3835 150.1048 0054331  11.7585 348.4873 14.49228725466907",
		       "1 35487U 97051QH  18072.03965486  .00003025  00000-0  69169-3 0  9992",
		       "2 35487  86.3404 163.6689 0057663 103.2854  20.4687 14.54365827463187",
		       "1 35488U 97051QJ  18072.88860425  .00000550  00000-0  12114-3 0  9991",
		       "2 35488  86.3359 117.5071 0039649 318.9845  40.8382 14.55123307469314",
		       "1 35615U 97051QM  18072.05236988  .00023835  00000-0  99683-3 0  9990",
		       "2 35615  86.3598  96.8372 0007038  85.5612 274.6437 15.23451438474544",
		       "1 35616U 97051QN  18072.47773950  .00000693  00000-0  17535-3 0  9995",
		       "2 35616  86.3685 143.0734 0020694  43.0463 317.2355 14.49455676465925",
		       "1 35617U 97051QP  18072.58467189  .00007236  00000-0  84350-3 0  9991",
		       "2 35617  86.4899 198.8766 0051270 271.3677  88.1673 14.84133696463596",
		       "1 35618U 97051QQ  18072.90238048  .00000318  00000-0  86681-4 0  9992",
		       "2 35618  86.3435 137.5440 0035042  63.9366 296.5435 14.43805275244884",
		       "1 35620U 97051QS  18071.52141177  .00001302  00000-0  70745-3 0  9995",
		       "2 35620  86.3987 272.6671 0234513 115.1776 247.3920 13.98526041445993",
		       "1 35622U 97051QU  18071.84334870  .00001050  00000-0  30370-3 0  9996",
		       "2 35622  86.2224 105.0233 0029597 108.3452  16.3101 14.43400313463708",
		       "1 35624U 97051QW  18072.20535671  .00004230  00000-0  78948-3 0  9997",
		       "2 35624  86.3590 160.5425 0045762  71.0639 289.5525 14.64083923467920",
		       "1 35625U 97051QX  18072.49323212  .00000461  00000-0  21630-3 0  9993",
		       "2 35625  86.2043 159.1668 0132351 173.0448 247.9548 14.13436452456551",
		       "1 35627U 97051QZ  18072.55724279  .00002221  00000-0  55036-3 0  9993",
		       "2 35627  86.3576 161.4032 0048662  76.7464 283.9162 14.50802302463624",
		       "1 35628U 97051RA  18072.49664356  .00000657  00000-0  18577-3 0  9996",
		       "2 35628  86.3685 153.0548 0020928  71.8239 288.5238 14.44025340460978",
		       "1 35629U 97051RB  18072.28714994  .00002325  00000-0  46186-3 0  9999",
		       "2 35629  86.3710 183.3244 0113497 149.3942 211.3955 14.57644529457889",
		       "1 35631U 97051RD  18072.17187338  .00000186  00000-0  50482-4 0  9994",
		       "2 35631  86.3727 151.2283 0020653 125.5677 266.1318 14.41853653463565",
		       "1 35632U 97051RE  18072.18358812  .00000773  00000-0  30395-3 0  9995",
		       "2 35632  86.4300 232.4231 0117174  46.6948 314.3940 14.24304631451986",
		       "1 35678U 97051RG  18072.59059754  .00003493  00000-0  48828-3 0  9995",
		       "2 35678  86.3562 125.0314 0007033 157.2189 202.9344 14.77343175463383",
		       "1 35679U 97051RH  18071.40638999  .00009944  00000-0  96690-3 0  9996",
		       "2 35679  86.3159 121.3787 0018687 193.1946 166.8795 14.92333468465343",
		       "1 35680U 97051RJ  18072.53727118  .00000182  00000-0  93665-4 0  9990",
		       "2 35680  86.1111 160.6230 0199852  61.0653   0.6343 13.99454705447407",
		       "1 35732U 97051RK  18072.90299291  .00003008  00000-0  79060-3 0  9997",
		       "2 35732  86.2389 122.0078 0061281 118.5985 242.1402 14.47702964459651",
		       "1 35735U 97051RN  18072.82344188  .00004167  00000-0  40443-3 0  9997",
		       "2 35735  86.3763 110.7220 0015338 102.0453 258.2495 14.92306761468200",
		       "1 35737U 97051RQ  18071.13791847  .00002427  00000-0  57654-3 0  9999",
		       "2 35737  86.4280 199.5930 0052304 150.3299 334.5924 14.52691417467124",
		       "1 35739U 97051RS  18072.57618019  .00004060  00000-0  82282-3 0  9999",
		       "2 35739  86.3967 182.7233 0064058 108.6199 252.1981 14.59717567465107",
		       "1 35742U 97051RV  18072.56319892  .00001451  00000-0  32549-3 0  9991",
		       "2 35742  86.4301 188.8677 0040793 336.6463  23.2890 14.55410766464090",
		       "1 35744U 97051RX  18071.46285470  .00000566  00000-0  14162-3 0  9992",
		       "2 35744  86.3370 129.1000 0033471  22.4926 337.7736 14.49422759462845",
		       "1 35745U 97051RY  18072.28679740  .00004110  00000-0  10604-2 0  9996",
		       "2 35745  86.3616 192.4232 0074066 229.9328 129.5366 14.48169086456900",
		       "1 35747U 97051SA  18067.50779259  .00002304  00000-0  11287-2 0  9994",
		       "2 35747  86.1313 157.4586 0175407 327.3460  31.6970 14.09812699178365",
		       "1 35749U 97051SC  18072.17756032  .00001511  00000-0  35885-3 0  9999",
		       "2 35749  86.3820 152.9180 0013845 237.0981 122.8894 14.53268301446353",
		       "1 35797U 97051SF  18071.48076845  .00000727  00000-0  18203-3 0  9995",
		       "2 35797  86.3488 135.0821 0025183  32.5253 327.7496 14.49927385462775",
		       "1 35799U 97051SH  18072.50524242  .00002136  00000-0  50656-3 0  9994",
		       "2 35799  85.9394 355.5797 0084436  15.2624 345.1097 14.51363022470387",
		       "1 35800U 97051SJ  18072.26521267  .00004539  00000-0  42268-3 0  9993",
		       "2 35800  86.2613  61.7205 0028696  44.1995 316.1518 14.93738553472633",
		       "1 35802U 97051SL  18071.15882150  .00002988  00000-0  87482-3 0  9996",
		       "2 35802  86.4601 222.9640 0094958 238.6209 246.8848 14.41059941466829",
		       "1 35805U 97051SP  18071.03653980  .00001242  00000-0  47600-3 0  9993",
		       "2 35805  86.3300 193.5893 0109254  35.4669 325.3723 14.26589376448805",
		       "1 35806U 97051SQ  18072.49568693  .00000581  00000-0  18217-3 0  9998",
		       "2 35806  86.3535 157.3765 0019486  78.3154 282.0229 14.38776226455380",
		       "1 35809U 97051ST  18071.92045316  .00000714  00000-0  18970-3 0  9994",
		       "2 35809  86.3388 136.6508 0025178  52.4244  72.5390 14.47099910456786",
		       "1 35844U 97051SU  18072.76923089  .00005565  00000-0  50497-3 0  9997",
		       "2 35844  86.3029  89.6591 0015466 199.1969 160.8680 14.95035059460402",
		       "1 35846U 97051SW  18072.01857246  .00000191  00000-0  60364-4 0  9993",
		       "2 35846  86.3847 173.3996 0021235  92.0026 268.3602 14.34686956450732",
		       "1 35848U 97051SY  18072.49557939  .00000710  00000-0  18446-3 0  9993",
		       "2 35848  86.4046 158.8073 0017071  55.2971 304.9838 14.48263724255294",
		       "1 35850U 97051TA  18071.49386828  .00000662  00000-0  16909-3 0  9990",
		       "2 35850  86.3621 142.1464 0020800  49.0374 311.2625 14.48886550462458",
		       "1 35851U 97051TB  18072.04254420  .00003329  00000-0  70595-3 0  9999",
		       "2 35851  86.4192 187.7434 0068130  70.8823 289.9746 14.57427155253707",
		       "1 35853U 97051TD  18072.46941204  .00002786  00000-0  67772-3 0  9999",
		       "2 35853  86.3078 152.2680 0070707 107.1740 253.7222 14.50938255448509",
		       "1 35856U 97051TG  18070.66919049  .00004613  00000-0  77986-3 0  9993",
		       "2 35856  86.3735 142.7627 0057925 214.6262 298.1998 14.68068770454715",
		       "1 35857U 97051TH  18063.99206745 -.00008232  00000-0 -16088-2 0  9992",
		       "2 35857  86.4348 159.7046 0042461 334.9749  16.2252 14.62585251463584",
		       "1 35858U 97051TJ  18071.69439884  .00003387  00000-0  76484-3 0  9992",
		       "2 35858  86.3591 163.0256 0008434  17.1175 343.0316 14.56023724272978",
		       "1 35862U 97051TN  18072.93175148  .00003512  00000-0  51199-3 0  9991",
		       "2 35862  86.3727 136.7657 0032551 187.8210 297.4657 14.75183986312106",
		       "1 35863U 97051TP  18071.99238417  .00003756  00000-0  10354-2 0  9993",
		       "2 35863  86.3439 172.9238 0083776 192.3389 167.5764 14.44560749452414",
		       "1 35911U 97051TU  18072.51328239  .00001623  00000-0  62347-3 0  9999",
		       "2 35911  86.2386 151.2043 0089927 348.2933  11.6166 14.27699602463197",
		       "1 35915U 97051TY  18070.95285479  .00000715  00000-0  18515-3 0  9996",
		       "2 35915  86.3578 142.2568 0024827  44.8631 315.4573 14.48287831452633",
		       "1 35917U 97051UA  18071.94778947  .00003154  00000-0  61906-3 0  9997",
		       "2 35917  86.3946 146.0596 0018957 278.2459  81.6603 14.62329081453216",
		       "1 35918U 97051UB  18072.60559091  .00000496  00000-0  16433-3 0  9990",
		       "2 35918  86.4130 185.9619 0033699 126.5085 295.4207 14.35589537447358",
		       "1 35921U 97051UE  18072.72123169  .00001948  00000-0  79866-3 0  9992",
		       "2 35921  86.4244 242.3516 0141327 144.0553 217.0245 14.21374210461145",
		       "1 35922U 97051UF  18068.48997088  .00001111  00000-0  26186-3 0  9999",
		       "2 35922  86.3945 156.5579 0028879   9.8445 350.3320 14.53180237239217",
		       "1 35925U 97051UJ  18072.86208366  .00003652  00000-0  53186-3 0  9995",
		       "2 35925  86.3168 116.6133 0017428 122.7660 237.5241 14.75502768468002",
		       "1 35926U 97051UK  18072.11388064  .00001497  00000-0  31195-3 0  9999",
		       "2 35926  86.3472 130.4052 0008040  35.5286 324.6458 14.59339850458728",
		       "1 35929U 97051UN  18071.91139774  .00000823  00000-0  18872-3 0  9990",
		       "2 35929  86.3517 128.9441 0029423 343.8790  16.1478 14.54128316464458",
		       "1 36011U 97051US  18072.02187767  .00000263  00000-0  86359-4 0  9995",
		       "2 36011  86.3488 160.0735 0022886 121.3159 359.1958 14.34225861448080",
		       "1 36012U 97051UT  18069.11200587  .00000500  00000-0  29650-3 0  9992",
		       "2 36012  86.4548 320.8125 0306274 285.1978  71.5516 13.85349371441516",
		       "1 36017U 97051UY  18071.41477117  .00003920  00000-0  52809-3 0  9999",
		       "2 36017  86.3669 129.1860 0017098 126.5056 293.5107 14.78845324248900",
		       "1 36019U 97051VA  18072.51084670  .00001124  00000-0  25985-3 0  9990",
		       "2 36019  86.3981 152.9320 0010716  90.7717 325.8659 14.54309179451195",
		       "1 36021U 97051VC  18072.17243341  .00002103  00000-0  72883-3 0  9994",
		       "2 36021  86.4185 226.5942 0126041  17.4381 343.1081 14.30827715177603",
		       "1 36023U 97051VE  18072.48539638  .00001611  00000-0  39035-3 0  9992",
		       "2 36023  86.3431 147.4964 0024320   8.3273 351.8331 14.52245996261246",
		       "1 36025U 97051VG  18068.25977324  .00002629  00000-0  60878-3 0  9991",
		       "2 36025  86.5642 252.6195 0058751 118.5025 242.2115 14.53691386450751",
		       "1 36028U 97051VK  18071.91906333  .00000792  00000-0  18422-3 0  9990",
		       "2 36028  86.3373 124.5363 0032544 343.9678  16.0495 14.53359986458558",
		       "1 36080U 97051VM  18070.50029494  .00000166  00000-0  48915-4 0  9992",
		       "2 36080  86.3268 147.0309 0021751 121.2727 239.0605 14.37194279448215",
		       "1 36081U 97051VN  18072.89480663  .00001838  00000-0  54121-3 0  9998",
		       "2 36081  86.2371 130.2833 0068725 184.3906 175.6701 14.41786996214173",
		       "1 36083U 97051VQ  18072.52932325  .00000333  00000-0  10944-3 0  9991",
		       "2 36083  86.3512 159.7327 0031694 138.1066 222.2564 14.34965391448991",
		       "1 36390U 97051VU  18068.42195280 -.00000069  00000-0 -23212-4 0  9998",
		       "2 36390  86.3030 117.5720 0046887  10.8758 349.3448 14.49736204471038",
		       "1 36482U 97051VY  18071.44399311  .00000821  00000-0  19612-3 0  9999",
		       "2 36482  86.3452 132.0412 0020921  36.6639 323.5994 14.52350673454625",
		       "1 36483U 97051VZ  18071.99623899  .00000321  00000-0  10184-3 0  9991",
		       "2 36483  86.3891 170.0850 0011746  80.4824 279.7700 14.36815185244203",
		       "1 36485U 97051WB  18072.17441553  .00001761  00000-0  65798-3 0  9999",
		       "2 36485  86.4472 240.3995 0124711  58.8109 302.5237 14.27105798430494",
		       "1 36486U 97051WC  18070.60950179  .00001113  00000-0  21989-3 0  9990",
		       "2 36486  86.3562 132.2843 0014598 291.3751  68.5902 14.61459484248490",
		       "1 36487U 97051WD  18072.77449902  .00001976  00000-0  95790-3 0  9996",
		       "2 36487  86.3696 245.8423 0175126 302.6828  55.7567 14.10343961429267",
		       "1 36488U 97051WE  18072.17698344  .00016187  00000-0  92743-3 0  9992",
		       "2 36488  86.4369 147.2220 0009218  48.6834 311.5197 15.12467491218006",
		       "1 36490U 97051WG  18071.98833945  .00000659  00000-0  18079-3 0  9998",
		       "2 36490  86.3814 156.1037 0004131 137.9907 222.1613 14.45648731453868",
		       "1 36492U 97051WJ  18071.02371413  .00001686  00000-0  38039-3 0  9991",
		       "2 36492  86.4294 171.2891 0014271 221.6861 138.3260 14.55720837462736",
		       "1 36493U 97051WK  18070.99168514  .00000582  00000-0  16632-3 0  9992",
		       "2 36493  86.3687 154.4543 0018434  80.1456 280.1825 14.43390664461057",
		       "1 36495U 97051WM  18072.17767573  .00007328  00000-0  75229-3 0  9998",
		       "2 36495  86.3942 145.8944 0016891 140.7562 219.4893 14.90161413276681",
		       "1 36497U 97051WP  18068.83770994  .00000692  00000-0  22295-3 0  9991",
		       "2 36497  86.1579  92.6948 0075179 104.2924  20.4413 14.36193427247968",
		       "1 36563U 97051WS  18069.47147598  .00002082  00000-0  32739-3 0  9993",
		       "2 36563  86.3601 136.0138 0032063 294.6113  65.1764 14.71737618453366",
		       "1 36566U 97051WV  18072.30011453  .00001677  00000-0  76141-3 0  9996",
		       "2 36566  86.4275 263.8584 0170485 285.8620  72.3830 14.13969001442368",
		       "1 36642U 97051XC  18072.49084883  .00002625  00000-0  50502-3 0  9995",
		       "2 36642  86.3741 148.0228 0024104 201.0891 158.9329 14.63074218312817",
		       "1 37136U 97051XG  18070.45124397  .00000294  00000-0  12450-3 0  9993",
		       "2 37136  86.1758 129.9699 0086235  28.4377 332.1476 14.19996325455488",
		       "1 37548U 97051XH  18072.51371954  .00000505  00000-0  17009-3 0  9992",
		       "2 37548  86.3631 168.8982 0032966 134.0586 226.3333 14.34802820452017",
		       "1 37549U 97051XJ  18072.01409004  .00002828  00000-0  64663-3 0  9994",
		       "2 37549  86.3873 174.7752 0041141  43.7170 316.7282 14.54866784452644",
		       "1 37550U 97051XK  18072.02120803  .00000636  00000-0  18030-3 0  9996",
		       "2 37550  86.3898 161.0620 0002895 164.2443 195.8849 14.44054991453184",
		       "1 37555U 97051XQ  18072.62157303  .00002610  00000-0  57736-3 0  9992",
		       "2 37555  86.4646 199.1849 0026231  92.6087 267.8124 14.56675472440216",
		       "1 37557U 97051XS  18072.13707150  .00002681  00000-0  98795-3 0  9999",
		       "2 37557  86.3790 224.2596 0129396 117.5877 243.8527 14.27651274444785",
		       "1 37558U 97051XT  18071.56280973  .00000928  00000-0  23533-3 0  9995",
		       "2 37558  86.4073 178.2331 0086724 119.5091 241.4796 14.47453511204088",
		       "1 37560U 97051XV  18066.15188834  .00002998  00000-0  94716-3 0  9990",
		       "2 37560  86.3939 212.1829 0096153 348.2867 136.8616 14.37318006422774",
		       "1 37562U 97051XX  18072.53544361  .00000530  00000-0  16503-3 0  9990",
		       "2 37562  86.3865 169.5271 0033419 111.4929 304.0512 14.38726405455008",
		       "1 37565U 97051YA  18066.97317337  .00000351  00000-0  10092-3 0  9993",
		       "2 37565  86.3565 149.6898 0016915 119.8869   6.3308 14.41928447443421",
		       "1 37566U 97051YB  18072.52655109  .00009588  00000-0  68756-3 0  9995",
		       "2 37566  86.4396 162.8323 0003782 270.9261  89.1540 15.04234146433093",
		       "1 38016U 97051YC  18072.58305824  .00004968  00000-0  71311-3 0  9996",
		       "2 38016  86.4038 166.1350 0030574 288.3529 136.7197 14.75982796355800",
		       "1 38017U 97051YD  18072.73793544  .00001494  00000-0  82282-3 0  9994",
		       "2 38017  86.3548 246.6426 0182877  29.9576 331.1916 14.02868890214160",
		       "1 38019U 97051YF  18072.11887200  .00003497  00000-0  95036-3 0  9997",
		       "2 38019  86.4019 204.4154 0083411 260.3728  98.8044 14.45249875420127",
		       "1 38020U 97051YG  18070.16571349  .00001281  00000-0  56168-3 0  9998",
		       "2 38020  86.3133 221.7310 0178805 298.5984  59.7312 14.14886980437672",
		       "1 38022U 97051YJ  18071.97206459  .00000416  00000-0  15789-3 0  9990",
		       "2 38022  86.2829 153.3740 0056591 226.9289 132.7159 14.27886113286879",
		       "1 38023U 97051YK  18071.15607388  .00002294  00000-0  69360-3 0  9997",
		       "2 38023  86.4151 226.2449 0103701   7.7754 352.5021 14.38896628435324",
		       "1 38024U 97051YL  18071.77564800  .00001824  00000-0  64207-3 0  9990",
		       "2 38024  86.4813 250.3441 0132148  47.1206 314.0993 14.29560457442357",
		       "1 38025U 97051YM  18072.85951569  .00001266  00000-0  53821-3 0  9993",
		       "2 38025  86.4944 279.3678 0168373 240.2836 180.9722 14.17270468457566",
		       "1 38028U 97051YQ  18072.94260208  .00000226  00000-0  65156-4 0  9999",
		       "2 38028  86.3306 140.3384 0032103 100.3838 260.0981 14.39823742247163",
		       "1 38030U 97051YS  18071.05150263  .00004613  00000-0  10615-2 0  9994",
		       "2 38030  86.3665 190.5354 0090446 201.7160 158.0202 14.52695448372173",
		       "1 38033U 97051YV  18070.99552129  .00003908  00000-0  44405-3 0  9997",
		       "2 38033  86.2746  74.5980 0023127 123.6141 236.7294 14.85820340837419",
		       "1 38224U 97051YY  18072.66727101  .00001905  00000-0  60605-3 0  9994",
		       "2 38224  86.3855 211.3008 0094782 357.9826   2.0974 14.36878740290350",
		       "1 38225U 97051YZ  18071.76360681  .00001434  00000-0  73185-3 0  9995",
		       "2 38225  86.3607 251.1986 0201370  39.0934 325.8161 14.05104840355360",
		       "1 38226U 97051ZA  18070.65946945  .00003626  00000-0  79188-3 0  9990",
		       "2 38226  86.3796 158.6000 0005132  64.5204 295.6535 14.57592021249044",
		       "1 38227U 97051ZB  18071.88097545  .00001011  00000-0  25030-3 0  9993",
		       "2 38227  86.3131 126.5332 0009158  42.5885 317.6029 14.51011689450837",
		       "1 38228U 97051ZC  18070.58730507  .00000190  00000-0  74526-4 0  9994",
		       "2 38228  86.3019 165.9427 0064630 273.3655 153.8831 14.23037274448262",
		       "1 38229U 97051ZD  18071.32346416  .00001352  00000-0  79936-3 0  9990",
		       "2 38229  86.3740 276.8993 0232505 160.8691 200.1401 13.94462530419678",
		       "1 38231U 97051ZF  18071.86283744  .00006364  00000-0  87152-3 0  9993",
		       "2 38231  86.2494 105.3062 0043925 277.1659 205.7617 14.77668908455164",
		       "1 38232U 97051ZG  18072.73812729  .00004060  00000-0  11478-2 0  9990",
		       "2 38232  86.4537 231.0269 0095166 264.1930  94.8415 14.42800899455806",
		       "1 38233U 97051ZH  18069.10811611 -.00000635  00000-0 -29287-3 0  9991",
		       "2 38233  86.2186 185.7659 0163320 265.8677 214.8177 14.15608739423451",
		       "1 38234U 97051ZJ  18072.31060471  .00002467  00000-0  48866-3 0  9996",
		       "2 38234  86.4505 192.8404 0059676 304.4861  55.0721 14.60785244435112",
		       "1 38235U 97051ZK  18072.91382709  .00003047  00000-0  49197-3 0  9997",
		       "2 38235  86.3940 149.8010 0014610 301.0577  58.9205 14.71025161181468",
		       "1 38236U 97051ZL  18072.91484105  .00001203  00000-0  40437-3 0  9991",
		       "2 38236  86.2523 141.2212 0069520 211.9903 147.7064 14.35024548207712",
		       "1 38237U 97051ZM  18072.94003678  .00004256  00000-0  59012-3 0  9997",
		       "2 38237  86.3772 141.1211 0018024 153.7145 332.9024 14.77633671217682",
		       "1 38241U 97051ZR  18072.90463108  .00000643  00000-0  18910-3 0  9994",
		       "2 38241  86.3289 138.8463 0005096  95.1887 264.9895 14.42225176193108",
		       "1 38243U 97051ZT  18070.96075583  .00002674  00000-0  58092-3 0  9997",
		       "2 38243  86.3781 151.4798 0043486 301.3825  58.3133 14.57154855389229",
		       "1 38244U 97051ZU  18071.49350918  .00005162  00000-0  59251-3 0  9998",
		       "2 38244  86.4287 149.9320 0003602 327.1672  32.9328 14.85680899432177",
		       "1 38468U 97051ZV  18062.64570410  .00002341  00000-0  82831-3 0  9990",
		       "2 38468  86.3535 195.0016 0076009 337.5602  22.2273 14.32643882410397",
		       "1 38469U 97051ZW  18072.11164732  .00002314  00000-0  10107-2 0  9996",
		       "2 38469  86.2790 206.8945 0188370 224.1371 134.4654 14.14488305457040",
		       "1 38470U 97051ZX  18072.24632209  .00002389  00000-0  77708-3 0  9994",
		       "2 38470  86.4970 247.4589 0105404 311.3735 171.3168 14.35306986464145",
		       "1 38471U 97051ZY  18072.77247683  .00004833  00000-0  52751-3 0  9998",
		       "2 38471  86.2764  93.8104 0017075 179.8294 180.2940 14.87613807418230",
		       "1 38474U 97051AAB 18070.45671807  .00000077  00000-0  17612-4 0  9997",
		       "2 38474  86.3494 148.5497 0032404 100.5722 259.9130 14.40668217455237",
		       "1 38477U 97051AAE 18068.21853632  .00000884  00000-0  85596-3 0  9990",
		       "2 38477  86.4252  42.5567 0475671 305.1044  50.6368 13.38209921385837",
		       "1 39594U 97051AAG 18065.59029591  .00000887  00000-0  24315-3 0  9993",
		       "2 39594  86.4102 175.1288 0009154   2.1116 358.0123 14.46038749225743",
		       "1 39595U 97051AAH 18070.67322566  .00005275  00000-0  10465-2 0  9993",
		       "2 39595  86.3752 162.7693 0047752 328.3729  31.4613 14.61334174221329",
		       "1 39777U 97051AAJ 18072.25210602  .00000785  00000-0  31292-3 0  9991",
		       "2 39777  85.9801  53.6389 0087416 355.2338   4.8010 14.25281239196483",
		       "1 39778U 97051AAK 18072.02634358  .00000401  00000-0  12270-3 0  9995",
		       "2 39778  86.3892 168.1427 0010538  39.4993 320.6972 14.39322882198598",
		       "1 39779U 97051AAL 18071.99600786  .00001876  00000-0  63657-3 0  9991",
		       "2 39779  86.2966 157.4003 0066715 204.5850 279.7181 14.34972552302690",
		       "1 39781U 97051AAN 18071.92935281  .00001533  00000-0  92200-3 0  9994",
		       "2 39781  86.3786 295.0356 0291502 312.3132 109.5633 13.87370218327236",
		       "1 39782U 97051AAP 18072.96707237  .00002192  00000-0  37792-3 0  9995",
		       "2 39782  86.4187 151.3318 0013121 287.7407 197.3324 14.68034512326093",
		       "1 39783U 97051AAQ 18071.36922775  .00000764  00000-0  24806-3 0  9990",
		       "2 39783  86.1681 106.4463 0066377 233.9174 183.0466 14.36387187197771",
		       "1 39785U 97051AAS 18072.50009439  .00010793  00000-0  87389-3 0  9990",
		       "2 39785  86.3868 144.4526 0033787 135.5183 287.6758 14.99169121325616",
		       "1 39786U 97051AAT 18070.16319421  .00002463  00000-0  44812-3 0  9995",
		       "2 39786  86.3728 142.7505 0011001 179.0507 210.5612 14.65708634304979",
		       "1 39787U 97051AAU 18072.80572024  .00001663  00000-0  42219-3 0  9999",
		       "2 39787  86.2041  96.0800 0045329  82.9012  42.0440 14.49594941320835",
		       "1 39788U 97051AAV 18069.59849799  .00061220  00000-0  41831-2 0  9991",
		       "2 39788  86.3053 193.2445 0036762 350.9900   9.0670 15.05331063378108",
		       "1 39790U 97051AAX 18067.75847883  .00001701  00000-0  36163-3 0  9993",
		       "2 39790  86.1871  75.1151 0043933  28.9902 331.3733 14.57874680191760",
		       "1 39791U 97051AAY 18064.29739793  .00006354  00000-0  19923-2 0  9993",
		       "2 39791  86.3624 251.1667 0160087 318.2403 161.5366 14.33360725293940",
		       "1 39792U 97051AAZ 18072.27691650  .00001825  00000-0  98200-3 0  9994",
		       "2 39792  86.4276 276.5071 0184199  15.8707 344.8137 14.04095048193539",
		       "1 39793U 97051ABA 18071.85238115  .00009282  00000-0  55659-3 0  9997",
		       "2 39793  86.3482 108.6980 0010035  78.3673 281.8691 15.10788111205295",
		       "1 40992U 97051ABE 18063.93646157  .00002873  00000-0  61065-3 0  9996",
		       "2 40992  86.3034 123.3277 0022839  12.3984 108.6261 14.58602843319329",
		       "1 40993U 97051ABF 18072.18261740  .00002982  00000-0  58163-3 0  9991",
		       "2 40993  86.3787 151.3809 0019016 256.2691 133.1534 14.62591855298624",
		       "1 40994U 97051ABG 18069.92643840  .00002117  00000-0  37691-3 0  9998",
		       "2 40994  86.3947 141.3705 0005046 308.7231  51.3531 14.66639192183710",
		       "1 40995U 97051ABH 18070.05205039  .00001261  00000-0  34935-3 0  9996",
		       "2 40995  86.3961 173.7173 0042930  95.8652  26.5962 14.45321285297850",
		       "1 40996U 97051ABJ 18072.52299948  .00000641  00000-0  17206-3 0  9996",
		       "2 40996  86.3780 155.6695 0010573 238.1344 179.5816 14.46599104213017",
		       "1 40997U 97051ABK 18069.86188188  .00006915  00000-0  70817-3 0  9990",
		       "2 40997  86.3589 126.5497 0014382  77.2648 283.0186 14.90280955353457",
		       "1 40998U 97051ABL 18070.54859090  .00000252  00000-0  78007-4 0  9993",
		       "2 40998  86.3930 171.0089 0009234  38.9873  19.5640 14.37109208663626"] ;

     
  
  

    var timeSinceTleEpochMinutes = 1 ;
    var debrisRecords = [] ;
    var datasetSize = spaceDebris.length;
    console.log(datasetSize);
    var posVel = [];
    var positionEci = [];
    var velocityEci = [];
    var positionEcf = [];
    var positionGd = [];

    var now = new Date();

    var gmst = satellite.gstimeFromDate(
	now.getUTCFullYear(),
	now.getUTCMonth() + 1, // Note, this function requires months in range 1-12.
	now.getUTCDate(),
	now.getUTCHours(),
	now.getUTCMinutes(),
	now.getUTCSeconds()
    );

    console.log("gmst = " + gmst);
    console.log("date = " + now);

    function orbitalDebris() {
	var j = 0;

	for (var i = 0; i < datasetSize; i++) {
	    var tle1 = spaceDebris[j];
	    var tle2 = spaceDebris[j + 1];
	    if (typeof tle2 == 'string' || tle1 instanceof String || typeof tle2 == 'string' || tle2 instanceof String ) {
		debrisRecords[i] = satellite.twoline2satrec (tle1, tle2);
	    }
	    j = j + 2;
	}

	// propagate debris using time since epoch
	for (i=0; i < datasetSize; i++) {
	    if (debrisRecords[i] != undefined ) {
		posVel[i] = satellite.sgp4(debrisRecords[i], timeSinceTleEpochMinutes);
		posVel[i] = satellite.propagate(debrisRecords[i],
						now.getUTCFullYear(),
						now.getUTCMonth() + 1, // Note, this function requires months in range 1-12.
						now.getUTCDate(),
						now.getUTCHours(),
						now.getUTCMinutes(),
						now.getUTCSeconds()
					       );
		positionEci[i] = posVel[i].position;
		velocityEci[i] = posVel[i].velocity;
	//	console.log("pos.x = " + posVel[i].position.x,
	//		    "pos.y = " + posVel[i].position.y,
	//		    "pos.z = " + posVel[i].position.z,);
	//	console.log("pos2.x = " + positionEci[i].position.x);
	    }
	}
	//positionEci = posVel.position;
	
    }

    function startUpdate() {
//	for (i=0; i < datasetSize; i++) {
//	    var positionEcf[i] = satellite.eciToEcf(positionEci[i], gmst),
//		positionGd[i] = satellite.eciToGeodetic(positionEci[i], gmst);
//	}
	var position = [];
	var placemark = [];

	//var str0 = JSON.stringify(posVel);
	//console.log(str0);
	//alert(str0);

	//var positionEcf = satellite.eciToEcf(positionEci, gmst),
	//    positionGd = satellite.eciToGeodetic(positionEci, gmst);
	

	//console.log("long = " + positionGd.longitude);
	

	var km = 1000; //1km = 1000m
	var radiusE = 6371 // radius of Earth
	var arraySize = positionEci.length;
	console.log("array size: " + arraySize);
//	alert("array size: " + arraySize);
	
	for (var i=0; i < arraySize-1; i++) {

	    var str1 = JSON.stringify(positionEci[i]);
	   // console.log(str1);
	   // alert(str1);

	    //positionEcf[i] = satellite.eciToEcf(positionEci[i], gmst);
	    positionGd[i] = satellite.eciToGeodetic(positionEci[i], gmst);
	    var str2 = JSON.stringify(positionEcf[i]);
	    var str3 = JSON.stringify(positionGd[i]);
	    console.log(str2);
	    console.log(str3);
	  //  alert(str2);
	  //  alert(str3);

	    var longitude = positionGd[i].longitude; //longitude in degrees
	    var latitude = positionGd[i].latitude;  //latitude  in degrees
	    var height = positionGd[i].height //measured from the surface of the Earth in km
	    
	    var lon = satellite.degreesLong(longitude),
		lat = satellite.degreesLat(latitude),
		alt = (height + radiusE) * km; //altitude in metres
	    
	    console.log("latitude = " + lat,
			"longitude = " + lon,
			"height = " + height,
			"altitude = " + alt);
	    
	  
    

	    position[i] = new WorldWind.Position(lat, lon, alt);
	    placemark[i] = new WorldWind.Placemark(position[i], false, placemarkAttributes);
	    placemark.alwaysOnTop = true;
	    placemarkLayer.addRenderable(placemark[i]);	 



	    //let positionEci = Object.assign({}, posVel[i].position);
	    //console.log("test1 = " + posVel[i].position.x);
	    //console.log("test1 = " + positionEci.position.x);
	    //positionEci = posVel[i].position,
	    //velocityEci = posVel[i].velocity;
	    //var positionEcf = satellite.eciToEcf(positionEci, gmst),
	    //	positionGd = satellite.eciToGeodetic(positionEci, gmst);
	    //positionEci = posVel[i].position,
	    //velocityEci = posVel[i].velocity;

	    //  var positionEcf = satellite.eciToEcf(posVel[i].position, gmst),
	   // var test = [posVel[i].position.x, posVel[i].position.y, posVel[i].position.z];
	   // var positionGd = satellite.eciToGeodetic(test, gmst);
	    
	    
	    //var lon = positionGd.longitude; //longitude in degrees
	    //var lat = positionGd.latitude;  //latitude  in degrees
	    //var height = positionGd.height //measured from the surface of the Earth in km
	    //var alt = (height + radiusE) * km; //altitude in metres
	    
	    //console.log("latitude = " + lat,
	//		"longitude = " + lon,
	//		"altitude = " + alt);
    

	  //  position[i] = new WorldWind.Position(lat, lon, alt);
	  //  placemark[i] = new WorldWind.Placemark(position[i], false, placemarkAttributes);
	  //  placemark.alwaysOnTop = true;
	  //  placemarkLayer.addRenderable(placemark[i]);	 

	    
	    
	}
	    
    }

    orbitalDebris();
    startUpdate();

   //var satrec = satellite.twoline2satrec(tleLine1, tleLine2);

    //console.log(satrec);

   //var positionAndVelocity = satellite.propagate(
    //satrec,
   // now.getUTCFullYear(),
   // now.getUTCMonth() + 1, // Note, this function requires months in range 1-12.
   // now.getUTCDate(),
   // now.getUTCHours(),
   // now.getUTCMinutes(),
   // now.getUTCSeconds()
   //);
    
    //var positionAndVelocity = satellite.sgp4(satrec, timeSinceTleEpochMinutes);
    //var positionAndVelocity = satellite.propagate(satrec, now);
    //console.log("position = " + positionAndVelocity.position.y);

  //  var positionEci = positionAndVelocity.position,
//	velocityEci = positionAndVelocity.velocity;


    // Set the Observer at 122.03 West by 36.96 North, in RADIANS
    //var observerGd = {
//	longitude: satellite.degreesToRadians(-122.0308),
//	latitude: satellite.degreesToRadians(36.9613422),
//	height: 0.370
  //  };
    
    // You will need GMST for some of the coordinate transforms.
    // http://en.wikipedia.org/wiki/Sidereal_time#Definition
    //var gmst = satellite.gstime(new Date());
    
    // You can get ECF, Geodetic, Look Angles, and Doppler Factor.
 // var positionEcf   = satellite.eciToEcf(positionEci, gmst),
//	positionGd    = satellite.eciToGeodetic(positionEci, gmst);

    
    // The coordinates are all stored in key-value pairs.
    // ECI and ECF are accessed by `x`, `y`, `z` properties.
  //var satelliteX = positionEci.x,
  //	satelliteY = positionEci.y,
//	satelliteZ = positionEci.z;

    // Geodetic coords are accessed via `longitude`, `latitude`, `height`.
   //var longitude = positionGd.longitude,
//	latitude  = positionGd.latitude,
//	height    = positionGd.height;

  //  console.log("longitude = " + longitude,
//		"latitude = " + latitude,
//		"height = " + height);

  //  var arrayLength = 2;
   // var altitude = (height + 6371) * 1000;
   // var position = new WorldWind.Position(latitude, longitude, altitude);
   // var placemark = new WorldWind.Placemark(position, false, placemarkAttributes);
  //  placemark.alwaysOnTop = true;
  //  placemarkLayer.addRenderable(placemark);
    

    //var arrayLength = 2;
    //for (var i=0; i < arrayLength; i++){
//	altitude = (height + 6371) * 1000;
//	position[i] = new WorldWind.Position(latitude, longitude, altitude);
//	placemark[i] = new WorldWind.Placemark(position[i], false, placemarkAttributes);
//	placemark.alwaysOnTop = true;
//	placemarkLayer.addRenderable(placemark[i]);	
//    }

    

    //var gmst = satellite.gstime(new Date());
    //var satelliteX = positionEci.x;
    //console.log(satelliteX);

    //var positionEcf   = satellite.eciToEcf(positionEci, gmst),
    //observerEcf   = satellite.geodeticToEcf(observerGd),
//	positionGd    = satellite.eciToGeodetic(positionEci, gmst);
	//lookAngles    = satellite.ecfToLookAngles(observerGd, positionEcf) ;

  //  var longitude = positionGd.longitude,
//	latitude  = positionGd.latitude,
//	height    = positionGd.height;

    //console.log(longitude);
    //console.log(latitude);
    //console.log(height);
    
    // Initialize a satellite record
    // var satrec = satellite.twoline2satrec(tleLine1, tleLine2);
    // var timeSinceTleEpochMinutes = 1 ;
    
//    var position = [];
//    var placemark = [];
//    var lat = [0.119, -0.121, 0.100, 0.016, -0.025];
//    var lon = [70.155, 57.229, -154.877, 157.307, -18.400];
//    var alt = [3003847.326,1808966.641, 2460210.929, 3543654.129, 664981.347];
//    //(0.016, 157.307, 3543654.129);
//    //(-0.025, -18.400, 513683.148);
//    //(-0.115, 40.240, 664981.347)
//    //
//    var arrayLength = lat.length-1;
//    for (var i=0; i <= arrayLength; i++){
//	position[i] = new WorldWind.Position(lat[i], lon[i], alt[i]);
//	placemark[i] = new WorldWind.Placemark(position[i], false, placemarkAttributes);
//	placemark.alwaysOnTop = true;
//	placemarkLayer.addRenderable(placemark[i]);	
//    }

  

  // Create the view models
  let layers = new LayersViewModel(globe);
  let settings = new SettingsViewModel(globe);
  let preview = new PreviewViewModel(globe);
  let search = new SearchViewModel(globe, preview.previewResults);


  // Bind the views to the view models
  ko.applyBindings(layers, document.getElementById('layers'));
  ko.applyBindings(settings, document.getElementById('settings'));
  ko.applyBindings(search, document.getElementById('search'));
  ko.applyBindings(preview, document.getElementById('preview'));

  // Auto-collapse the main menu when its button items are clicked
  $('.navbar-collapse a[role="button"]').click(function() {
    $('.navbar-collapse').collapse('hide');
  });

  // Collapse card ancestors when the close icon is clicked
  $('.collapse .close').on('click', function() {
    $(this).closest('.collapse').collapse('hide');
  });
});
